@@ -3,13 +3,13 @@ import json
 
 # create a base class for the cache client
 class CacheClient(ClientModel):
+    '''cache client is a client model that is used to store data in a cache file'''
     def __init__(self, cacheFileFullPath, *args, force=False, **kwargs):
         self.cacheFileFullPath = cacheFileFullPath
         try:
             self.dict = self.__loads()
-        except Exception as err:
+        except FileNotFoundError as err:
             if not force:
-                print(err)
                 raise Exception("Cache file not found") from err
             else:
                 self.save({})
